"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// @ts-ignore
const ecc = require("eosjs-ecc");
const eosjs_numeric_1 = require("eosjs/dist/eosjs-numeric");
class NodeEosjsSignatureProvider {
    constructor(privateKeys) {
        this.keys = new Map();
        if (privateKeys.length === 0)
            throw new Error("At least one private key must be specified");
        this.privateKeys = privateKeys;
        switch (process.platform) {
            case "linux":
                this.module = require("node-eosjs-signature-provider-linux/build/Release/node-eosjs-signature-provider.node");
                break;
            case "darwin":
                this.module = require("node-eosjs-signature-provider-osx/build/Release/node-eosjs-signature-provider.node");
                break;
            default:
                throw new Error(`This module only works on Darwin (MacOS) and Linux. Your os is ${process.platform}`);
        }
    }
    getAvailableKeys() {
        return this.generateKeyPairs().then(() => Array.from(this.keys.keys()));
    }
    sign({ chainId, requiredKeys, serializedTransaction }) {
        return this.generateKeyPairs()
            .then(() => new Promise(resolve => {
            let privateKeys = requiredKeys
                .map(key => this.keys.get(key))
                .filter(pkey => pkey);
            const signBuf = Buffer.concat([
                Buffer.from(chainId, 'hex'),
                Buffer.from(serializedTransaction),
                Buffer.from(new Uint8Array(32)),
            ]);
            resolve({
                serializedTransaction: serializedTransaction,
                signatures: this.module.sign(privateKeys, signBuf)
            });
        }));
    }
    generateKeyPairs() {
        if (this.keys.size !== 0)
            return Promise.resolve();
        return Promise.all(this.privateKeys.map(privateKey => {
            let publicKey = ecc.PrivateKey.fromString(privateKey).toPublic().toString();
            this.keys.set(publicKey, privateKey);
            this.keys.set(eosjs_numeric_1.convertLegacyPublicKey(publicKey), privateKey);
        }));
    }
}
exports.default = NodeEosjsSignatureProvider;
//# sourceMappingURL=index.js.map